tynt
----

.. image:: https://readthedocs.org/projects/tynt/badge/?version=latest
   :target: https://tynt.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

.. image:: https://github.com/bmorris3/tynt/workflows/CI%20Tests/badge.svg
   :target: https://github.com/bmorris3/tynt/actions

.. image:: http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat
   :target: http://www.astropy.org
   :alt: Powered by Astropy Badge

.. image:: https://github.com/bmorris3/tynt/blob/main/docs/assets/logo.svg
    :alt: tynt logo
    :width: 200
    :align: right

Astronomical color filters (almost). See `docs for details <https://tynt.readthedocs.io>`_.

License
-------

This project is Copyright (c) Brett M. Morris and licensed under
the terms of the BSD 3-Clause license. This package is based upon
the `Openastronomy packaging guide <https://github.com/OpenAstronomy/packaging-guide>`_
which is licensed under the BSD 3-clause licence. See the licenses folder for
more information.
